@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,29 +14,31 @@
  * limitations under the License.
  */
 
-#ifndef _SERVER_H
-#define _SERVER_H
+#ifndef ZNC_SERVER_H
+#define ZNC_SERVER_H
 
 #include <znc/zncconfig.h>
 #include <znc/ZNCString.h>
 
 class CServer {
-public:
-	CServer(const CString& sName, unsigned short uPort = 6667, const CString& sPass = "", bool bSSL = false);
-	~CServer();
+  public:
+    CServer(const CString& sName, unsigned short uPort = 6667,
+            const CString& sPass = "", bool bSSL = false);
+    ~CServer();
 
-	const CString& GetName() const;
-	unsigned short GetPort() const;
-	const CString& GetPass() const;
-	bool IsSSL() const;
-	CString GetString(bool bIncludePassword = true) const;
-	static bool IsValidHostName(const CString& sHostName);
-private:
-protected:
-	CString         m_sName;
-	unsigned short  m_uPort;
-	CString         m_sPass;
-	bool            m_bSSL;
+    const CString& GetName() const;
+    unsigned short GetPort() const;
+    const CString& GetPass() const;
+    bool IsSSL() const;
+    CString GetString(bool bIncludePassword = true) const;
+    static bool IsValidHostName(const CString& sHostName);
+
+  private:
+  protected:
+    CString m_sName;
+    unsigned short m_uPort;
+    CString m_sPass;
+    bool m_bSSL;
 };
 
-#endif // !_SERVER_H
+#endif  // !ZNC_SERVER_H
