@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,9 +20,9 @@
 #define BUILD_WITH_CMAKE 1
 
 #define VERSION_MAJOR 1
-#define VERSION_MINOR 7
-#define VERSION_PATCH 5
-#define VERSION_STR "1.7.5"
+#define VERSION_MINOR 8
+#define VERSION_PATCH 2
+#define VERSION_STR "1.8.2"
 #define VERSION_EXTRA ""
 
 /* #undef _GLIBCXX_DEBUG */
@@ -42,7 +42,7 @@
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_CLOCK_GETTIME 1
 
-/* #undef HAVE_ICU */
+#define HAVE_ICU 1
 #define U_USING_ICU_NAMESPACE 1
 
 /* #undef _LARGE_FILES */
